import { Injectable } from '@nestjs/common';
import { ConfigService } from '@nestjs/config';
import { Client, mapping, auth, types } from 'cassandra-driver';
import * as fs from 'fs';

@Injectable()
export class DbService {
  client: Client;
  mapping: mapping.Mapper;

  constructor(private configService: ConfigService) {}

  private createClient() {
    console.log(process.env);
    this.client = new Client({
      contactPoints: [process.env.CASSANDRA_HOST],
      keyspace: 'quriverse',
      localDataCenter: process.env.CASSANDRA_DC,
      authProvider: new auth.PlainTextAuthProvider(process.env.CASSANDRA_USER, process.env.CASSANDRA_PW),
      sslOptions: {
        ca: [
          fs.readFileSync('sf-class2-root.crt', 'utf-8')
        ],
        host: 'cassandra.ap-south-1.amazonaws.com',
        rejectUnauthorized: true,
      },
      protocolOptions: {
        port: process.env.ENVIRONMENT === "production" ? 9142 : 9042,
      },
      queryOptions: {
        consistency: process.env.ENVIRONMENT === "production" ? types.consistencies.localQuorum : types.consistencies.localOne,
      },
    });
  }

  createMapper(mappingOptions: mapping.MappingOptions) {
    if (this.client == undefined) {
      this.createClient();
    }
    
    return new mapping.Mapper(this.client, mappingOptions);
  }
}
