import { Injectable, OnModuleInit } from '@nestjs/common';
import { mapping } from 'cassandra-driver';
import { User } from './user.model';
import { DbService } from '../db/db.service';

@Injectable()
export class UserRepository implements OnModuleInit {
  constructor(private dbService: DbService) {}

  mapper: mapping.ModelMapper<User>;

  onModuleInit() {
    const mappingOptions: mapping.MappingOptions = {
      models: {
        'User': {
          tables: ['users'],
          mappings: new mapping.UnderscoreCqlToCamelCaseMappings
        }
      }
    }

    this.mapper = this.dbService.createMapper(mappingOptions).forModel('User');
  }

  async get() {
    return (await this.mapper.findAll()).toArray();
  }

  async create(user: User) {
    return (await this.mapper.insert(user)).toArray();
  }
}
